==> coeus-db-sql-mysql-2510.0002.jar: co/kuali/coeus/data/migration/sql/mysql/rice/bootstrap/V2011_002__RESKC-4766.sql <==
-- -
-- #%L
-- %%
-- Copyright (C) 2005 - 2025 Kuali, Inc. - All Rights Reserved
-- %%
-- You may use and modify this code under the terms of the Kuali, Inc.
-- Pre-Release License Agreement. You may not distribute it.
-- 
-- You should have received a copy of the Kuali, Inc. Pre-Release License
-- Agreement with this file. If not, please write to license@kuali.co.
-- #L%
-- -

INSERT INTO KRCR_PARM_T (APPL_ID, NMSPC_CD, PARM_TYP_CD, CMPNT_CD, PARM_NM, PARM_DESC_TXT, VAL, EVAL_OPRTR_CD, OBJ_ID,
                         VER_NBR)
VALUES ('KC', 'KC-AWARD', 'AUTH', 'Document', 'LIMITED_EDITABILITY_AWARD_ATTACHMENT_TYPES',
        'Comma delimited list of Award Attachment Types to be editable when having the permission Limited Modify Award Attachments.', '', 'A', UUID(), 1);

INSERT INTO KRIM_PERM_T (PERM_ID, PERM_TMPL_ID, NMSPC_CD, NM, DESC_TXT, ACTV_IND, OBJ_ID, VER_NBR)
VALUES ('RESBOOT-1034',
        (SELECT PERM_TMPL_ID FROM KRIM_PERM_TMPL_T WHERE NMSPC_CD = 'KC-IDM' AND NM = 'Edit Document Section'),
        'KC-AWARD', 'Limited Modify Award Attachments', 'Grants users permission to edit specific Award Attachments as specified by the LIMITED_EDITABILITY_AWARD_ATTACHMENT_TYPES parameter when an Award would otherwise be read-only.', 'Y', UUID(), '1');

INSERT INTO KRIM_PERM_ATTR_DATA_T (ATTR_DATA_ID, PERM_ID, KIM_TYP_ID, KIM_ATTR_DEFN_ID, ATTR_VAL, OBJ_ID, VER_NBR)
VALUES ('RESBOOT-1031', 'RESBOOT-1034',
        (SELECT KIM_TYP_ID FROM KRIM_TYP_T WHERE NMSPC_CD = 'KR-SYS' AND NM = 'Document Type (Permission)'),
        (SELECT KIM_ATTR_DEFN_ID FROM KRIM_ATTR_DEFN_T WHERE NMSPC_CD = 'KR-WKFLW' AND NM = 'documentTypeName'),
        'AwardDocument', UUID(), '1');

INSERT INTO KRIM_PERM_ATTR_DATA_T (ATTR_DATA_ID, PERM_ID, KIM_TYP_ID, KIM_ATTR_DEFN_ID, ATTR_VAL, OBJ_ID, VER_NBR)
VALUES ('RESBOOT-1032', 'RESBOOT-1034',
        (SELECT KIM_TYP_ID FROM KRIM_TYP_T WHERE NMSPC_CD = 'KC-SYS' AND NM = 'Document Section'),
        (SELECT KIM_ATTR_DEFN_ID FROM KRIM_ATTR_DEFN_T WHERE NMSPC_CD = 'KC-SYS' AND NM = 'sectionName'),
        'award_attachments', UUID(), '1');

==> coeus-db-sql-mysql-2511.0005.jar: co/kuali/coeus/data/migration/sql/mysql/rice/bootstrap/V2011_004__RESKC-4766.sql <==
-- -
-- #%L
-- %%
-- Copyright (C) 2005 - 2025 Kuali, Inc. - All Rights Reserved
-- %%
-- You may use and modify this code under the terms of the Kuali, Inc.
-- Pre-Release License Agreement. You may not distribute it.
-- 
-- You should have received a copy of the Kuali, Inc. Pre-Release License
-- Agreement with this file. If not, please write to license@kuali.co.
-- #L%
-- -

INSERT INTO KRCR_PARM_T (APPL_ID, NMSPC_CD, PARM_TYP_CD, CMPNT_CD, PARM_NM, PARM_DESC_TXT, VAL, EVAL_OPRTR_CD, OBJ_ID,
                         VER_NBR)
VALUES ('KC', 'KC-AWARD', 'AUTH', 'Document', 'LIMITED_EDITABILITY_REPORT_CLASSES',
        'Comma delimited list of Award Report Classes to be editable when having the permission Limited Modify Award Report Classes.', '', 'A', UUID(), 1);

INSERT INTO KRIM_PERM_T (PERM_ID, PERM_TMPL_ID, NMSPC_CD, NM, DESC_TXT, ACTV_IND, OBJ_ID, VER_NBR)
VALUES ('RESBOOT-1035',
        (SELECT PERM_TMPL_ID FROM KRIM_PERM_TMPL_T WHERE NMSPC_CD = 'KC-IDM' AND NM = 'Edit Document Section'),
        'KC-AWARD', 'Limited Modify Award Report Classes', 'Grants users permission to edit specific Award Report Classes as specified by the LIMITED_EDITABILITY_REPORT_CLASSES parameter when an Award would otherwise be read-only.', 'Y', UUID(), '1');

INSERT INTO KRIM_PERM_ATTR_DATA_T (ATTR_DATA_ID, PERM_ID, KIM_TYP_ID, KIM_ATTR_DEFN_ID, ATTR_VAL, OBJ_ID, VER_NBR)
VALUES ('RESBOOT-1033', 'RESBOOT-1035',
        (SELECT KIM_TYP_ID FROM KRIM_TYP_T WHERE NMSPC_CD = 'KR-SYS' AND NM = 'Document Type (Permission)'),
        (SELECT KIM_ATTR_DEFN_ID FROM KRIM_ATTR_DEFN_T WHERE NMSPC_CD = 'KR-WKFLW' AND NM = 'documentTypeName'),
        'AwardDocument', UUID(), '1');

INSERT INTO KRIM_PERM_ATTR_DATA_T (ATTR_DATA_ID, PERM_ID, KIM_TYP_ID, KIM_ATTR_DEFN_ID, ATTR_VAL, OBJ_ID, VER_NBR)
VALUES ('RESBOOT-1034', 'RESBOOT-1035',
        (SELECT KIM_TYP_ID FROM KRIM_TYP_T WHERE NMSPC_CD = 'KC-SYS' AND NM = 'Document Section'),
        (SELECT KIM_ATTR_DEFN_ID FROM KRIM_ATTR_DEFN_T WHERE NMSPC_CD = 'KC-SYS' AND NM = 'sectionName'),
        'award_report_classes', UUID(), '1');
